' AVR Interface for a PAK-I or PAK-II math coprocessor
' Would also work for PAK-III, IV, VII, and VIII
' http://www.al-williams.com/awce

' These routines are written in assembly inlined for
' BASCOM AVR. That way if you are using BASCOM, fine.
' If not, you can pull the assembly routines out
' and use them

' For some operations, the PAK assumes you will wait
' a short amount of time between operations
' However, for any time-consuming operation, it will
' keep the data line high until ready to send

' This code as developed for AT90S2343 @ 1Mhz
' If you use a different speed change the $crystal line
' and you will need to adjust the Pakw routine to delay
' about 10uS or more.

' The code assumes the PAK data line is on B.4 and the clock
' is on B.3. You need a pullup resistor on B4 (either external
' or use the built-in pullup).

' The main test code toggles all of the PAK-I digital outputs
' and makes a simple computation. Then it compares the result
' to the known value and extinguishes an LED on B.0 -- if the
' LED stays lit the answer is not correct.

' Not all of the commands are implemented due to size constraints. However, using paksend
' and pakrcv any of the commands could be written using Basic or assembly

' To use include this file (pakdef.inc) at the start of your program
' include pak1.inc at the end
' pak1.bas is an example of using the library.
Config Pinb.4 = Output                                        ' data
Config Pinb.3 = Output                                        ' clock
Dim Pakrv As Byte                                             ' Result from many PAK commands
Declare Sub Pakreset                                          ' always reset PAK at start
Declare Sub Paksend(byval V As Byte)                          ' Send a byte to PAK
Declare Function Pakrcv(byval Pkwait As Byte) As Byte         ' Read a byte from PAK
Declare Function Pakreadint() As Integer                      ' read 16-bit integer
Declare Sub Pakloadx(byval Xhi As Integer , Byval Xlo As Integer)       ' load 32-bit float
Declare Sub Pakloady(byval Xhi As Integer , Byval Xlo As Integer)       ' load 32-bit float (Y)
Declare Sub Pakloadint(byval X As Integer)                    ' Load X with 16-bit integer
Declare Sub Pakmult()                                         ' multiply X=X*Y
Declare Sub Pakadd()                                          ' X=X+Y
Declare Sub Paksub()                                          ' X=X-Y
Declare Sub Pakdiv()                                          ' X=X/Y
Declare Sub Pakswap()                                         ' X<>Y
Declare Sub Pakdir(byval B As Byte)                           ' Set data direction
Declare Sub Pakwio(byval B As Byte)                           ' Write to PAK output
